caellion-python-commons: caellion/pycommons/encoding/base36.py File Reference

caellion-python-commons

Classes | Namespaces
base36.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.encoding.base36.InvalidCustomCharsetLengthException
| This exception is raised when custom character set length . More...
class | caellion.pycommons.encoding.base36.InvalidCustomCharsetException
| This exception is raised when more than exactly one instance of a given field is contained within field list. More...
class | caellion.pycommons.encoding.base36.InvalidInputStringException
| This exception is raised when encountering a character not defined in custom charset in input string. More...
class | caellion.pycommons.encoding.base36.NumberNotPositiveOrZeroException
| This exception is raised when non-positive integer is passed to encode function. More...
class | caellion.pycommons.encoding.base36.ValueTooLargeException
| This exception is raised when encountering an integer over maximum size of 16 bytes. More...
class | caellion.pycommons.encoding.base36.Base36Coder
| This class provides methods allowing conversion between integer, hexadecimal integer and base36 strings. More...

## Namespaces
| caellion.pycommons.encoding.base36
| This module provides utlilities related to converting to/from base36 encoding.